# oper8

Oper8 is a framework for writing kubernetes operators in python. It implements many common patterns used by large cloud applications that are reusable across many operator design patterns.

Documentation: https://ibm.github.io/oper8/
